import React from 'react';
import { Meta, Story, ComponentStory } from '@storybook/react';

import { SchemaUtils } from '@graphpolaris/shared/lib/schema/schema-utils';
import { schemaSlice, setSchema } from '@graphpolaris/shared/lib/data-access/store';

import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';

import { Schema } from '../../../panel';

const Component: Meta<typeof Schema> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Schema/Pills/RelationNode',

  component: Schema,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

// Mock the schema and palette store
const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
  },
});

export const Default = {
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology({
      nodes: [
        {
          name: 'Thijs',
          attributes: [
            { name: 'city', type: 'string' },
            { name: 'vip', type: 'bool' },
            { name: 'state', type: 'string' },
          ],
        },
      ],
      edges: [
        {
          name: 'Thijs:Thijs',
          from: 'Thijs',
          to: 'Thijs',
          collection: 'flights',
          attributes: [
            { name: 'arrivalTime', type: 'int' },
            { name: 'departureTime', type: 'int' },
          ],
        },
      ],
    });

    dispatch(setSchema(schema.export()));
  },
};

export default Component;
